webpackJsonp([83],{mD5y:function(i,e,n){(function(i){"use strict";var e="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},n={weekdays:{shorthand:["Dum","Lun","Mar","Mie","Joi","Vin","Sam"],longhand:["Duminică","Luni","Marți","Miercuri","Joi","Vineri","Sâmbătă"]},months:{shorthand:["Ian","Feb","Mar","Apr","Mai","Iun","Iul","Aug","Sep","Oct","Noi","Dec"],longhand:["Ianuarie","Februarie","Martie","Aprilie","Mai","Iunie","Iulie","August","Septembrie","Octombrie","Noiembrie","Decembrie"]},firstDayOfWeek:1,ordinal:function(){return""}};e.l10ns.ro=n;var r=e.l10ns;i.Romanian=n,i.default=r,Object.defineProperty(i,"__esModule",{value:!0})})(e)}});
//# sourceMappingURL=83.377d66e6516d13507c6c.js.map