webpackJsonp([113],{AwLy:function(a,n,e){(function(a){"use strict";var n="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},e={weekdays:{shorthand:["søn","man","tir","ons","tors","fre","lør"],longhand:["søndag","mandag","tirsdag","onsdag","torsdag","fredag","lørdag"]},months:{shorthand:["jan","feb","mar","apr","maj","jun","jul","aug","sep","okt","nov","dec"],longhand:["januar","februar","marts","april","maj","juni","juli","august","september","oktober","november","december"]},ordinal:function(){return"."},firstDayOfWeek:1,rangeSeparator:" til ",weekAbbreviation:"uge"};n.l10ns.da=e;var r=n.l10ns;a.Danish=e,a.default=r,Object.defineProperty(a,"__esModule",{value:!0})})(n)}});
//# sourceMappingURL=113.215e3d6b9a60ae5f4d4d.js.map