# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-31 15:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('modoboa_radicale', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='sharedcalendar',
            name='color',
            field=models.CharField(default='#3a87ad', max_length=7),
        ),
        migrations.AddField(
            model_name='usercalendar',
            name='color',
            field=models.CharField(default='#3a87ad', max_length=7),
        ),
    ]
