webpackJsonp([105],{ti8u:function(e,r,i){(function(e){"use strict";var r="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},i={firstDayOfWeek:1,weekdays:{shorthand:["Dim","Lun","Mar","Mer","Jeu","Ven","Sam"],longhand:["Dimanche","Lundi","Mardi","Mercredi","Jeudi","Vendredi","Samedi"]},months:{shorthand:["Janv","Févr","Mars","Avr","Mai","Juin","Juil","Août","Sept","Oct","Nov","Déc"],longhand:["Janvier","Février","Mars","Avril","Mai","Juin","Juillet","Août","Septembre","Octobre","Novembre","Décembre"]},ordinal:function(e){return e>1?"ème":"er"},rangeSeparator:" au ",weekAbbreviation:"Sem",scrollTitle:"Défiler pour augmenter la valeur",toggleTitle:"Cliquer pour basculer"};r.l10ns.fr=i;var n=r.l10ns;e.French=i,e.default=n,Object.defineProperty(e,"__esModule",{value:!0})})(r)}});
//# sourceMappingURL=105.bd352c8b696320d151e6.js.map