webpackJsonp([102],{"8blO":function(n,d,e){(function(n){"use strict";var d="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},e={weekdays:{shorthand:["रवि","सोम","मंगल","बुध","गुरु","शुक्र","शनि"],longhand:["रविवार","सोमवार","मंगलवार","बुधवार","गुरुवार","शुक्रवार","शनिवार"]},months:{shorthand:["जन","फर","मार्च","अप्रेल","मई","जून","जूलाई","अग","सित","अक्ट","नव","दि"],longhand:["जनवरी ","फरवरी","मार्च","अप्रेल","मई","जून","जूलाई","अगस्त ","सितम्बर","अक्टूबर","नवम्बर","दिसम्बर"]}};d.l10ns.hi=e;var o=d.l10ns;n.Hindi=e,n.default=o,Object.defineProperty(n,"__esModule",{value:!0})})(d)}});
//# sourceMappingURL=102.6376e23afa68d40acd39.js.map