webpackJsonp([95],{j39J:function(n,o,e){(function(n){"use strict";var o="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},e={weekdays:{shorthand:["일","월","화","수","목","금","토"],longhand:["일요일","월요일","화요일","수요일","목요일","금요일","토요일"]},months:{shorthand:["1월","2월","3월","4월","5월","6월","7월","8월","9월","10월","11월","12월"],longhand:["1월","2월","3월","4월","5월","6월","7월","8월","9월","10월","11월","12월"]},ordinal:function(){return"일"}};o.l10ns.ko=e;var d=o.l10ns;n.Korean=e,n.default=d,Object.defineProperty(n,"__esModule",{value:!0})})(o)}});
//# sourceMappingURL=95.dea15e012a457f3ef95e.js.map