webpackJsonp([116],{VFLW:function(e,r,n){(function(e){"use strict";var r="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},n={weekdays:{shorthand:["Dg","Dl","Dt","Dc","Dj","Dv","Ds"],longhand:["Diumenge","Dilluns","Dimarts","Dimecres","Dijous","Divendres","Dissabte"]},months:{shorthand:["Gen","Febr","Març","Abr","Maig","Juny","Jul","Ag","Set","Oct","Nov","Des"],longhand:["Gener","Febrer","Març","Abril","Maig","Juny","Juliol","Agost","Setembre","Octubre","Novembre","Desembre"]},ordinal:function(e){var r=e%100;if(r>3&&r<21)return"è";switch(r%10){case 1:return"r";case 2:return"n";case 3:return"r";case 4:return"t";default:return"è"}},firstDayOfWeek:1};r.l10ns.cat=n;var t=r.l10ns;e.Catalan=n,e.default=t,Object.defineProperty(e,"__esModule",{value:!0})})(r)}});
//# sourceMappingURL=116.b8dff981d4fe4d802b17.js.map